@@ -1,4 +1,4 @@
-__version__ = '1.1.7'
+__version__ = '1.1.8'
 
 import requests
 import json
@@ -119,6 +119,7 @@ class StreamBot:
           # Using the Server Sent Events library to support "Stream" of tokens to simulate the AI typing out
           client = sseclient.SSEClient(response)
           # Array to capture the tokens since `response` will no longer be consumable
+          last_yielded_message = ''
           for event in client.events():
               try:
                   data = json.loads(event.data)
@@ -128,9 +129,12 @@ class StreamBot:
                     # In first event, `delta` doesn't exist, so we check if the ['delta']['content'] keys are present
                     # Also check for ['finish_reason'] to break on last message
                     if choices.get('delta',{}).get('role',{}):
-                        yield '[START_OF_STREAM]' #Helper string to know when to render new chat content
+                        if last_yielded_message.strip() != '[START_OF_STREAM]':
+                          yield '[START_OF_STREAM]' #Helper string to know when to render new chat content
+                          last_yielded_message = '[START_OF_STREAM]'
                     if choices.get('delta',{}).get('content') and choices['finish_reason'] != 'stop':
                         yield choices['delta']['content']
+                        last_yielded_message = choices['delta']['content']
               except json.decoder.JSONDecodeError:
                   pass
       except requests.exceptions.RequestException as e:
